class FileExtension:
    CSV = ".csv"
    JPG = ".jpg"
    JSON = ".json"
    NUMPY = ".npy"
    PNG = ".png"
    TEXT = ".txt"
